/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 France Telecom R&D
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: ReliableJMSTransportConfiguration.java 21483 2011-06-23 14:47:13Z jppouzol $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.cxf.transport.reliablejms;

import java.util.List;

import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.Queue;

import org.ow2.jonas.cxf.transport.reliablejms.api.AsyncHandler;

/**
 * Configuration used for the transport.
 * @author Florent Benoit
 */
public class ReliableJMSTransportConfiguration {

    public static final String TEXT_MESSAGE_TYPE = "text";
    public static final String BINARY_MESSAGE_TYPE = "binary";
    public static final String BYTE_MESSAGE_TYPE = "byte";

    private String messageType = TEXT_MESSAGE_TYPE;

    private ConnectionFactory connectionFactory = null;

    private Queue queue = null;

    private Destination replyToDestination = null;

    private Destination targetDestination = null;

    private List<AsyncHandler> asyncHandlers = null;

    public ConnectionFactory getConnectionFactory() {
        return connectionFactory;
    }

    public Queue getQueue() {
        return queue;
    }

    public void setQueue(Queue queue) {
        this.queue = queue;
    }

    public void setConnectionFactory(ConnectionFactory connectionFactory) {
        this.connectionFactory = connectionFactory;
    }

    public String getMessageType() {
        return messageType;
    }

    public void setMessageType(String messageType) {
        this.messageType = messageType;
    }

    public Destination getReplyToDestination() {
        return replyToDestination;
    }

    public void setReplyToDestination(Destination replyToDestination) {
        this.replyToDestination = replyToDestination;
    }

    public Destination getTargetDestination() {
        return targetDestination;
    }

    public void setTargetDestination(Destination targetDestination) {
        this.targetDestination = targetDestination;
    }

    public void setAsyncHandlers(List<AsyncHandler> asyncHandlers) {
        this.asyncHandlers = asyncHandlers;
    }

    public List<AsyncHandler> getAsyncHandlers() {
        return asyncHandlers;
    }

}
