/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 France Telecom R&D
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: ReliableJMSTransportDestination.java 21483 2011-06-23 14:47:13Z jppouzol $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.cxf.transport.reliablejms;

import java.util.logging.Logger;

import org.apache.cxf.Bus;
import org.apache.cxf.common.logging.LogUtils;
import org.apache.cxf.interceptor.OneWayProcessorInterceptor;
import org.apache.cxf.message.Message;
import org.apache.cxf.service.model.EndpointInfo;
import org.apache.cxf.transport.AbstractDestination;
import org.apache.cxf.transport.Conduit;
import org.apache.cxf.transport.Destination;
import org.apache.cxf.transport.DestinationWithEndpoint;
import org.apache.cxf.wsdl.EndpointReferenceUtils;

public class ReliableJMSTransportDestination extends AbstractDestination implements Destination, DestinationWithEndpoint {

    /**
     * Logger.
     */
    private static final Logger LOG = LogUtils.getL7dLogger(ReliableJMSTransportDestination.class);

    private ReliableJMSTransportConfiguration reliableJMSTransportConfiguration = null;

    private ReliableJMSTransportModeType mode = null;

    public ReliableJMSTransportDestination(ReliableJMSTransportModeType mode, Bus bus, EndpointInfo endpointInfo,
                                           ReliableJMSTransportConfiguration reliableJMSTransportConfiguration) {
        super(bus, getTargetReference(endpointInfo, bus), endpointInfo);
        this.reliableJMSTransportConfiguration = reliableJMSTransportConfiguration;
        this.mode = mode;
        endpointInfo.setProperty(OneWayProcessorInterceptor.USE_ORIGINAL_THREAD, Boolean.TRUE);
    }

    @Override
    protected Conduit getInbuiltBackChannel(Message message) {
        return new ReliableJMSTransportConduit(mode, EndpointReferenceUtils.getAnonymousEndpointReference(), reliableJMSTransportConfiguration);
    }

    @Override
    protected Logger getLogger() {
        return LOG;
    }

    public ReliableJMSTransportConfiguration getConfiguration() {
        return reliableJMSTransportConfiguration;
    }

    public ReliableJMSTransportModeType getMode() {
        return mode;
    }

}
